/* -*- mode: C; c-file-style: "linux" -*- */

/* MemProf -- memory profiler and leak detector
 * Copyright 1999, 2000, 2001, Red Hat, Inc.
 * Copyright 2002, Kristian Rietveld
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
/*====*/

#include "memprof.h"
#include "process.h"

typedef struct {
  Symbol *symbol;
  guint self;
  guint total;
  GList *inherited;
  GList *children;
} ProfileFunc;

typedef struct {
  ProfileFunc *function;
  guint bytes;
} ProfileFuncRef;

typedef struct {
  gint n_functions;
  ProfileFunc **functions;

  /* Private */
  MPProcess *process;
  GHashTable *function_hash;
  GHashTable *skip_hash;
} Profile;

Profile *profile_create (MPProcess *process, GSList *skip_funcs);
void profile_write (Profile *profile,
		    gchar *outfile);
void profile_free (Profile *profile);
